@@ -1,4 +1,4 @@
-use crate::gen::SchemaGenerator;
+use crate::r#gen::SchemaGenerator;
 use crate::schema::{InstanceType, ObjectValidation, Schema, SchemaObject};
 use crate::{JsonSchema, Map, Set};
 use serde::Serialize;
@@ -6,10 +6,10 @@ use serde_json::Value;
 
 // Helper for generating schemas for flattened `Option` fields.
 pub fn json_schema_for_flatten<T: ?Sized + JsonSchema>(
-    gen: &mut SchemaGenerator,
+    generator: &mut SchemaGenerator,
     required: bool,
 ) -> Schema {
-    let mut schema = T::_schemars_private_non_optional_json_schema(gen);
+    let mut schema = T::_schemars_private_non_optional_json_schema(generator);
 
     if T::_schemars_private_is_option() && !required {
         if let Schema::Object(SchemaObject {
@@ -131,7 +131,7 @@ pub fn insert_object_property<T: ?Sized + JsonSchema>(
     schema: Schema,
 ) {
     obj.properties.insert(key.to_owned(), schema);
-    if required || !(has_default || T::_schemars_private_is_option()) {
+    if !has_default && (required || !T::_schemars_private_is_option()) {
         obj.required.insert(key.to_owned());
     }
 }
@@ -161,7 +161,7 @@ pub mod metadata {
     add_metadata_fn!(add_deprecated, deprecated, bool);
     add_metadata_fn!(add_read_only, read_only, bool);
     add_metadata_fn!(add_write_only, write_only, bool);
-    add_metadata_fn!(add_default, default, Value);
+    add_metadata_fn!(add_default, default, Option<Value>);
 
     pub fn add_examples<I: IntoIterator<Item = Value>>(schema: Schema, examples: I) -> Schema {
         let mut schema_obj = schema.into_object();
