@@ -1,6 +1,7 @@
-use crate::gen::SchemaGenerator;
+use crate::r#gen::SchemaGenerator;
 use crate::schema::*;
 use crate::JsonSchema;
+use std::borrow::Cow;
 use uuid1::Uuid;
 
 impl JsonSchema for Uuid {
@@ -10,6 +11,10 @@ impl JsonSchema for Uuid {
         "Uuid".to_string()
     }
 
+    fn schema_id() -> Cow<'static, str> {
+        Cow::Borrowed("uuid::Uuid")
+    }
+
     fn json_schema(_: &mut SchemaGenerator) -> Schema {
         SchemaObject {
             instance_type: Some(InstanceType::String.into()),
